﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace ReflectionIT.Minesweeper {

    /// <summary>
    /// Source: http://www.robertjantuit.nl/index.php/2008/08/13/animateto-extension-methods-in-silverlight-2/
    /// </summary>
    public static class UIElementExtentions {

        public static void AnimateDoubleTo(this UIElement element, int miliseconds, string propertyPath, double value, EventHandler completed) {
            // Create a new storyboard
            var sb = new Storyboard();
            // Create a double animation
            var da = new DoubleAnimation();
            da.Duration = new TimeSpan(0, 0, 0, 0, miliseconds);
            // Set target property and target
            Storyboard.SetTargetProperty(da, new PropertyPath(propertyPath));
            Storyboard.SetTarget(da, element);
            da.To = value;
            // Add the doubleanimation to the storyboard
            sb.Children.Add(da);
            // Add the storyboard to the Rootvisual of the application
            ((FrameworkElement)Application.Current.RootVisual).Resources.Add(Guid.NewGuid().ToString(), sb);
            // Begin the animation
            sb.Begin();
            if (completed != null) {
                sb.Completed += completed;
            }
        }
    }

    public static class ScaleTransformExtentions {

        public static void AnimateTo(this ScaleTransform scaleTransform, int milliseconds, double scaleX, double scaleY, EventHandler completed) {

            var sb = new Storyboard();
            var daX = new DoubleAnimation();
            daX.Duration = new TimeSpan(0, 0, 0, 0, milliseconds);
            Storyboard.SetTargetProperty(daX, new PropertyPath("(ScaleTransform.ScaleX)"));
            Storyboard.SetTarget(daX, scaleTransform);
            daX.To = scaleX;
            var daY = new DoubleAnimation();

            daY.Duration = new TimeSpan(0, 0, 0, 0, milliseconds);

            Storyboard.SetTargetProperty(daY, new PropertyPath("(ScaleTransform.ScaleY)"));

            Storyboard.SetTarget(daY, scaleTransform);

            daY.To = scaleY;



            sb.Children.Add(daX);

            sb.Children.Add(daY);



            ((FrameworkElement)Application.Current.RootVisual).Resources.Add(Guid.NewGuid().ToString(), sb);



            sb.Begin();



            if (completed != null)

                sb.Completed += completed;

        }

    }



    public static class TranslateTransformExtentions {

        public static void AnimateTo(this TranslateTransform translateTransform, int milliseconds, double x, double y, EventHandler completed) {

            var sb = new Storyboard();



            var daX = new DoubleAnimation();

            daX.Duration = new TimeSpan(0, 0, 0, 0, milliseconds);

            Storyboard.SetTargetProperty(daX, new PropertyPath("(TranslateTransform.X)"));

            Storyboard.SetTarget(daX, translateTransform);

            daX.To = x;



            var daY = new DoubleAnimation();

            daY.Duration = new TimeSpan(0, 0, 0, 0, milliseconds);

            Storyboard.SetTargetProperty(daY, new PropertyPath("(TranslateTransform.Y)"));

            Storyboard.SetTarget(daY, translateTransform);

            daY.To = y;



            sb.Children.Add(daX);

            sb.Children.Add(daY);



            ((FrameworkElement)Application.Current.RootVisual).Resources.Add(Guid.NewGuid().ToString(), sb);



            sb.Begin();



            if (completed != null)

                sb.Completed += completed;

        }

    }



    public static class RotateTransformExtentions {

        public static void AnimateTo(this RotateTransform rotateTransform, int milliseconds, double angle, bool relative, EventHandler completed) {

            var sb = new Storyboard();



            if (relative)

                angle = rotateTransform.Angle + angle;



            var da = new DoubleAnimation();

            da.Duration = new TimeSpan(0, 0, 0, 0, milliseconds);



            Storyboard.SetTargetProperty(da, new PropertyPath("(RotateTransform.Angle)"));

            Storyboard.SetTarget(da, rotateTransform);

            da.To = angle;



            sb.Children.Add(da);



            ((FrameworkElement)Application.Current.RootVisual).Resources.Add(Guid.NewGuid().ToString(), sb);



            sb.Begin();



            if (completed != null)

                sb.Completed += completed;

        }

    }



}
